@@ -1,9 +1,10 @@
 """Animations related to rotation."""
 
+from __future__ import annotations
+
 __all__ = ["Rotating", "Rotate"]
 
-import typing
-from typing import Callable, Optional, Sequence
+from typing import TYPE_CHECKING, Callable, Sequence
 
 import numpy as np
 
@@ -12,21 +13,21 @@ from ..animation.transform import Transform
 from ..constants import OUT, PI, TAU
 from ..utils.rate_functions import linear
 
-if typing.TYPE_CHECKING:
+if TYPE_CHECKING:
     from ..mobject.mobject import Mobject
 
 
 class Rotating(Animation):
     def __init__(
         self,
-        mobject: "Mobject",
+        mobject: Mobject,
         axis: np.ndarray = OUT,
         radians: np.ndarray = TAU,
-        about_point: Optional[np.ndarray] = None,
-        about_edge: Optional[np.ndarray] = None,
+        about_point: np.ndarray | None = None,
+        about_edge: np.ndarray | None = None,
         run_time: float = 5,
         rate_func: Callable[[float], float] = linear,
-        **kwargs
+        **kwargs,
     ) -> None:
         self.axis = axis
         self.radians = radians
@@ -45,14 +46,49 @@ class Rotating(Animation):
 
 
 class Rotate(Transform):
+    """Animation that rotates a Mobject.
+
+    Parameters
+    ----------
+    mobject
+        The mobject to be rotated.
+    angle
+        The rotation angle.
+    axis
+        The rotation axis as a numpy vector.
+    about_point
+        The rotation center.
+    about_edge
+        If ``about_point``is ``None``, this argument specifies
+        the direction of the bounding box point to be taken as
+        the rotation center.
+
+    Examples
+    --------
+    .. manim:: UsingRotate
+
+        class UsingRotate(Scene):
+            def construct(self):
+                self.play(
+                    Rotate(
+                        Square(side_length=0.5).shift(UP * 2),
+                        angle=2*PI,
+                        about_point=ORIGIN,
+                        rate_func=linear,
+                    ),
+                    Rotate(Square(side_length=0.5), angle=2*PI, rate_func=linear),
+                    )
+
+    """
+
     def __init__(
         self,
-        mobject: "Mobject",
-        angle: np.ndarray = PI,
+        mobject: Mobject,
+        angle: float = PI,
         axis: np.ndarray = OUT,
-        about_point: Optional[Sequence[float]] = None,
-        about_edge: Optional[Sequence[float]] = None,
-        **kwargs
+        about_point: Sequence[float] | None = None,
+        about_edge: Sequence[float] | None = None,
+        **kwargs,
     ) -> None:
         if "path_arc" not in kwargs:
             kwargs["path_arc"] = angle
@@ -66,7 +102,7 @@ class Rotate(Transform):
             self.about_point = mobject.get_center()
         super().__init__(mobject, path_arc_centers=self.about_point, **kwargs)
 
-    def create_target(self) -> "Mobject":
+    def create_target(self) -> Mobject:
         target = self.mobject.copy()
         target.rotate(
             self.angle,
