@@ -1,21 +1,24 @@
 """Mobject representing curly braces."""
 
+from __future__ import annotations
+
 __all__ = ["Brace", "BraceLabel", "ArcBrace", "BraceText", "BraceBetweenPoints"]
 
-from typing import Optional, Sequence
+from typing import Sequence
 
 import numpy as np
 
 from manim._config import config
-from manim.mobject.opengl_compatibility import ConvertToOpenGL
+from manim.mobject.geometry.arc import Arc
+from manim.mobject.geometry.line import Line
+from manim.mobject.opengl.opengl_compatibility import ConvertToOpenGL
+from manim.mobject.text.tex_mobject import MathTex, Tex
 
 from ...animation.composition import AnimationGroup
 from ...animation.fading import FadeIn
 from ...animation.growing import GrowFromCenter
 from ...constants import *
-from ...mobject.geometry import Arc, Line
 from ...mobject.svg.svg_path import SVGPathMobject
-from ...mobject.svg.tex_mobject import MathTex, Tex
 from ...mobject.types.vectorized_mobject import VMobject
 from ...utils.color import BLACK
 
@@ -58,14 +61,14 @@ class Brace(SVGPathMobject):
     def __init__(
         self,
         mobject,
-        direction: Optional[Sequence[float]] = DOWN,
+        direction: Sequence[float] | None = DOWN,
         buff=0.2,
         sharpness=2,
         stroke_width=0,
         fill_opacity=1.0,
         background_stroke_width=0,
         background_stroke_color=BLACK,
-        **kwargs
+        **kwargs,
     ):
         path_string_template = (
             "m0.01216 0c-0.01152 0-0.01216 6.103e-4 -0.01216 0.01311v0.007762c0.06776 "
@@ -107,7 +110,7 @@ class Brace(SVGPathMobject):
             fill_opacity=fill_opacity,
             background_stroke_width=background_stroke_width,
             background_stroke_color=background_stroke_color,
-            **kwargs
+            **kwargs,
         )
         self.stretch_to_fit_width(target_width)
         self.shift(left - self.get_corner(UP + LEFT) + self.buff * DOWN)
@@ -156,7 +159,7 @@ class BraceLabel(VMobject, metaclass=ConvertToOpenGL):
         label_constructor=MathTex,
         font_size=DEFAULT_FONT_SIZE,
         buff=0.2,
-        **kwargs
+        **kwargs,
     ):
         self.label_constructor = label_constructor
         super().__init__(**kwargs)
@@ -236,10 +239,10 @@ class BraceBetweenPoints(Brace):
 
     def __init__(
         self,
-        point_1: Optional[Sequence[float]],
-        point_2: Optional[Sequence[float]],
-        direction: Optional[Sequence[float]] = ORIGIN,
-        **kwargs
+        point_1: Sequence[float] | None,
+        point_2: Sequence[float] | None,
+        direction: Sequence[float] | None = ORIGIN,
+        **kwargs,
     ):
         if all(direction == ORIGIN):
             line_vector = np.array(point_2) - np.array(point_1)
@@ -306,7 +309,7 @@ class ArcBrace(Brace):
         self,
         arc: Arc = Arc(start_angle=-1, angle=2, radius=1),
         direction: Sequence[float] = RIGHT,
-        **kwargs
+        **kwargs,
     ):
         arc_end_angle = arc.start_angle + arc.angle
         line = Line(UP * arc.start_angle, UP * arc_end_angle)
