@@ -33,7 +33,7 @@ class DefaultSectionType(str, Enum):
 
 class Section:
     """A :class:`.Scene` can be segmented into multiple Sections.
-    Refer to :doc:`the documentation</tutorials/a_deeper_look>` for more info.
+    Refer to :doc:`the documentation</tutorials/output_and_config>` for more info.
     It consists of multiple animations.
 
     Attributes
