@@ -22,6 +22,7 @@ __all__ = [
 
 import typing
 from functools import reduce
+from typing import Iterable
 
 import numpy as np
 from scipy import linalg
@@ -46,6 +47,23 @@ def bezier(
         function describing the bezier curve.
     """
     n = len(points) - 1
+
+    # Cubic Bezier curve
+    if n == 3:
+        return (
+            lambda t: (1 - t) ** 3 * points[0]
+            + 3 * t * (1 - t) ** 2 * points[1]
+            + 3 * (1 - t) * t**2 * points[2]
+            + t**3 * points[3]
+        )
+    # Quadratic Bezier curve
+    if n == 2:
+        return (
+            lambda t: (1 - t) ** 2 * points[0]
+            + 2 * t * (1 - t) * points[1]
+            + t**2 * points[2]
+        )
+
     return lambda t: sum(
         ((1 - t) ** (n - k)) * (t**k) * choose(n, k) * point
         for k, point in enumerate(points)
@@ -102,6 +120,117 @@ def partial_quadratic_bezier_points(points, a, b):
     return [h0, h1, h2]
 
 
+def split_quadratic_bezier(points: Iterable[float], t: float) -> np.ndarray:
+    """Split a quadratic Bézier curve at argument ``t`` into two quadratic curves.
+
+    Parameters
+    ----------
+    points
+        The control points of the bezier curve
+        has shape ``[a1, h1, b1]``
+
+    t
+        The ``t``-value at which to split the Bézier curve
+
+    Returns
+    -------
+        The two Bézier curves as a list of tuples,
+        has the shape ``[a1, h1, b1], [a2, h2, b2]``
+    """
+    a1, h1, a2 = points
+    s1 = interpolate(a1, h1, t)
+    s2 = interpolate(h1, a2, t)
+    p = interpolate(s1, s2, t)
+
+    return np.array([a1, s1, p, p, s2, a2])
+
+
+def subdivide_quadratic_bezier(points: Iterable[float], n: int) -> np.ndarray:
+    """Subdivide a quadratic Bézier curve into ``n`` subcurves which have the same shape.
+
+    The points at which the curve is split are located at the
+    arguments :math:`t = i/n` for :math:`i = 1, ..., n-1`.
+
+    Parameters
+    ----------
+    points
+        The control points of the Bézier curve in form ``[a1, h1, b1]``
+
+    n
+        The number of curves to subdivide the Bézier curve into
+
+    Returns
+    -------
+        The new points for the Bézier curve in the form ``[a1, h1, b1, a2, h2, b2, ...]``
+
+    .. image:: /_static/bezier_subdivision_example.png
+
+    """
+    beziers = []
+    current = points
+    for i in range(n, 0, -1):
+        tmp = split_quadratic_bezier(current, 1 / i)
+        beziers.append(tmp[:3])
+        current = tmp[3:]
+    return np.asarray(beziers).reshape(-1, 3)
+
+
+def quadratic_bezier_remap(
+    triplets: Iterable[Iterable[float]], new_number_of_curves: int
+):
+    """Remaps the number of curves to a higher amount by splitting bezier curves
+
+    Parameters
+    ----------
+    triplets
+        The triplets of the quadratic bezier curves to be remapped
+
+    new_number_of_curves
+        The number of curves that the output will contain. This needs to be higher than the current number.
+
+    Returns
+    -------
+        The new triplets for the quadratic bezier curves.
+    """
+    difference = new_number_of_curves - len(triplets)
+    if difference <= 0:
+        return triplets
+    new_triplets = np.zeros((new_number_of_curves, 3, 3))
+    idx = 0
+    for triplet in triplets:
+        if difference > 0:
+            tmp_noc = int(np.ceil(difference / len(triplets))) + 1
+            tmp = subdivide_quadratic_bezier(triplet, tmp_noc).reshape(-1, 3, 3)
+            for i in range(tmp_noc):
+                new_triplets[idx + i] = tmp[i]
+            difference -= tmp_noc - 1
+            idx += tmp_noc
+        else:
+            new_triplets[idx] = triplet
+            idx += 1
+    return new_triplets
+
+    """
+    This is an alternate version of the function just for documentation purposes
+    --------
+
+    difference = new_number_of_curves - len(triplets)
+    if difference <= 0:
+        return triplets
+    new_triplets = []
+    for triplet in triplets:
+        if difference > 0:
+            tmp_noc = int(np.ceil(difference / len(triplets))) + 1
+            tmp = subdivide_quadratic_bezier(triplet, tmp_noc).reshape(-1, 3, 3)
+            for i in range(tmp_noc):
+                new_triplets.append(tmp[i])
+            difference -= tmp_noc - 1
+        else:
+            new_triplets.append(triplet)
+    return new_triplets
+    """
+
+
 # Linear interpolation variants
 
 
@@ -461,7 +590,7 @@ def proportions_along_bezier_curve_for_point(
 
     roots = [[root for root in rootlist if root.imag == 0] for rootlist in roots]
     roots = reduce(np.intersect1d, roots)  # Get common roots.
-    roots = np.array([r.real for r in roots])
+    roots = np.array([r.real for r in roots if 0 <= r.real <= 1])
     return roots
 
 
