@@ -2,7 +2,12 @@
 
 from __future__ import annotations
 
-__all__ = ["get_full_raster_image_path", "drag_pixels", "invert_image"]
+__all__ = [
+    "get_full_raster_image_path",
+    "drag_pixels",
+    "invert_image",
+    "change_to_rgba_array",
+]
 
 import numpy as np
 from PIL import Image
@@ -32,3 +37,19 @@ def invert_image(image: np.array) -> Image:
     arr = np.array(image)
     arr = (255 * np.ones(arr.shape)).astype(arr.dtype) - arr
     return Image.fromarray(arr)
+
+
+def change_to_rgba_array(image, dtype="uint8"):
+    """Converts an RGB array into RGBA with the alpha value opacity maxed."""
+    pa = image
+    if len(pa.shape) == 2:
+        pa = pa.reshape(list(pa.shape) + [1])
+    if pa.shape[2] == 1:
+        pa = pa.repeat(3, axis=2)
+    if pa.shape[2] == 3:
+        alphas = 255 * np.ones(
+            list(pa.shape[:2]) + [1],
+            dtype=dtype,
+        )
+        pa = np.append(pa, alphas, axis=2)
+    return pa
